# OpenTTY 1.6.1 "The Resources Upgrade"

> This is OpenTTY, a terminal emulator  
> totally created in python that run a minimalist  
> version of shell into your system (Windows and Linux)  
> is supported by app.  

## OpenTTY 98

This is OpenTTY 98!  
In this release family the focus is implement some  
functions into OpenTTY and turn the users experience more  
cool and funny. If you found an issue, please report and  
help development team to turn the OpenTTY better.  
 
## Release Notes  

1. Removed password for FABRIC

In this release OpenTTY [Fabric] profile had your password removed  
adding a new daemon for ignore authentication if password setting is  
null. 

_It isn't recommended 'cause don't propose security_

2. New assets `figlet` and `rss`
3. New tests with Warnings recipient 
4. Added new manager `flush` to remove functions

Contributors: Mr. Lima  
GitHub Repository: https://github.com/fetuber4095/OpenTTY  

